@@ -137,6 +137,8 @@ const Application = new Lang.Class({
                     this.emitJS('prepare-shutdown');
             }));
             this._window.window.show_all();
+
+            this._chatroomManager.lateInit();
         }
         this._window.window.present();
     },
@@ -378,12 +380,14 @@ const Application = new Lang.Class({
             return;
         }
 
+        this.hold();
         this._connectionsDialog = new Connections.ConnectionsDialog();
         this._connectionsDialog.widget.show();
         this._connectionsDialog.widget.connect('response',
             Lang.bind(this, function(widget) {
                 widget.destroy();
                 this._connectionsDialog = null;
+                this.release();
             }));
     },
 
